"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""


import unittest

import lakefs_client
from lakefs_client.api.import_api import ImportApi  # noqa: E501


class TestImportApi(unittest.TestCase):
    """ImportApi unit test stubs"""

    def setUp(self):
        self.api = ImportApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_import_cancel(self):
        """Test case for import_cancel

        cancel ongoing import  # noqa: E501
        """
        pass

    def test_import_start(self):
        """Test case for import_start

        import data from object store  # noqa: E501
        """
        pass

    def test_import_status(self):
        """Test case for import_status

        get import status  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
