"""
    lakeFS API

    lakeFS HTTP API  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Contact: services@treeverse.io
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import lakefs_client
from lakefs_client.model.commit_creation import CommitCreation
from lakefs_client.model.import_location import ImportLocation
globals()['CommitCreation'] = CommitCreation
globals()['ImportLocation'] = ImportLocation
from lakefs_client.model.import_creation import ImportCreation


class TestImportCreation(unittest.TestCase):
    """ImportCreation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testImportCreation(self):
        """Test ImportCreation"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ImportCreation()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
